@@ -1,7 +1,14 @@
 from betterTUI import *
 
-def home(screen):
-    button = (Button(screen, 4, 2, "ENTER VAULT"), vault)
+def home(screen, child_obj=None):
+    button = Button(screen, 3, 2, "ENTER VAULT")
+    box = Box(screen, 2, 1, 20, 10)
+    box.clear()
+
+    button = (Button(screen, 14, 20, "ENTER VAULT"), vault)
+
+    if(child_obj):
+        print(child_obj.content)
 
     return [[button]]
 
